@@ -12,13 +12,17 @@ function ShowTooltip(item){
             var customconfig = <span tal:replace="structure view/get_custom_config" />;
             var settings = jq.extend({
                 tipClass:'',
+                cancelDefault: true,
                 layout: "<span tal:replace="structure view/get_tooltip_layout" />",
                 events: {
+                    def: "mouseenter,mouseleave mousedown",
                     tooltip: 'mouseleave'
                 }
             }, customconfig);
 
             $this.tooltip(settings);
+            // Manually remove title attribute (live event allways readds the title attr)
+            $this.attr('title', '');
 
             $this.data('tooltip').show();
         }
